#===================================================================
# Universidade Estadual de Santa Cruz - UESC
# Departamento de Cincias Agrrias e Ambientais - DCAA
# Curso: Agronomia
# Discentes: Charles Muniz, Joo Vitor Carvalho, Matheus Mota e
#            Willian Lima
# Disciplina: Metodologia e Estatstica Experimental
# Prof: Jos C. Faria
# Data: 2023-12-01 11:57:57
#=================================================================== 
# DELINEAMENTO EM BLOCOS CASUALIZADOS
# Exemplo: Produo (nmero de vagens/planta) de cinco variedades 
# de feijo preto (Phaseolus vulgaris)
#===================================================================

#. Entrada de dados
dad <- read.table('dbc.txt',
                  head=TRUE,
                  stringsAsFactors=TRUE) 

str(dad)
dad

#.. Verificao da adequao dos dados para realizao da ANOVA e TCMM
is.factor(dad$tra)
is.factor(dad$blo)
is.numeric(dad$pro)
 
#. Anlise exploratria dos dados
#.. boxplot
plot(pro ~ tra,
     data=dad,
     mean.labels=TRUE,
     digits=3,
     col=1:5,
     ylab='Nmero vagens/planta',
     xlab='Tratamentos')

library(gplots)

# Observar mdias de tratamentos
plotmeans(pro ~ tra,
          data=dad,
          pch=' ',
          mean.labels=TRUE,
          col=2,
          connect=FALSE,
          ylab='Nmero vagens/planta',
          xlab='Tratamentos')
                                       
# Observar gradiente das mdias dos blocos!
plotmeans(pro ~ blo,
          data=dad,
          pch=' ',
          mean.labels=TRUE,
          digits=3,
          col='hotpink',
          connect=FALSE,
          ylab='Nmero vagens/planta',
          xlab='Blocos')

#. Anlise de  varincia
av <- aov(pro ~ blo + tra,
          data=dad)
          
# Sumrio
summary(av)

#.. Valores F (quantis)
# Ftab: blo
(Ftab_blo <- qf(5/100,
                3,
                12,
                lower.tail=FALSE))

# Ftab: tra
(Ftab_tra <- qf(5/100,
                4,
                12,
                lower.tail=FALSE))
 
#. Teste de comparao de mdias
library(TukeyC)

#.. Tukey p/ blo
tk_blo <- TukeyC(av,
                 which='blo')

summary(tk_blo)

plot(tk_blo,
     disp='mm',
     ylab='Nmero vagens/planta',
     xlab='Blocos',
     pch=19)

#.. Tukey p/ tra
tk_tra <- TukeyC(av,
                 which='tra')

summary(tk_tra)

plot(tk_tra,
     disp='mm',
     ylab='Nmero vagens/planta',
     xlab='Tratamentos',
     pch=19)

#... Diferenciando os tratamentos: E de A
tk_tra <- TukeyC(av,
                 which='tra',
                 sig.level=7/100)

summary(tk_tra)

#.. ScottKnott
library(ScottKnott)

sk <- SK(av,
         which='tra')

summary(sk)

plot(sk,
     disp='mm',
     ylab='Nmero vagens/planta',
     xlab='Tratamentos',
     pch=19)

#. Contrastes
                                    # A   B   C   D   E
cmat <- rbind('(B,D) vs (C,E,A)' = c(-2,  3, -2,  3, -2),
              'B vs D'           = c( 0,  1,  0, -1,  0),
              'C vs (E,A)'       = c(-1,  0,  2,  0, -1),
              'E vs A'           = c(-1,  0,  0,  0,  1))
              
# install.packages('gmodels') 
library(gmodels)

av1 <- aov(pro ~ blo + tra,
           data=dad,
           contrasts=list(tra=make.contrasts(cmat))) # make.contrasts (gmodels)

effects(av1)[1:8]

summary(av1,                                          
        split=list(tra=list('(B,D) vs (C,E,A)'= 1,
                            'B vs D   '       = 2,
                            'C vs (E,A)'      = 3,
                            'E vs A'          = 4)))
                            
# Ftab: contrastes
(Ftab_ct <- qf(5/100,
               1,
               12,
               lower.tail=F))
                            

#. Complemento
#.. Mdias tratamentos
tapply(dad$pro,
       dad$tra,
       mean)

#.. Totais tratamentos
with(dad,
     tapply(pro,
            tra,
            sum))
       
#.. Soma totais tratamentos
with(dad,
     sum(tapply(pro,
                tra,
                sum)))

#.. Mdias blocos
with(dad,
     tapply(pro,
            blo,
            mean))

#.. Totais blocos
with(dad,
     tapply(pro,
            blo,
            sum))

#.. Soma totais blocos
with(dad,
     sum(tapply(pro,
                blo,
                sum)))
